# Generated by Django 4.0.10 on 2023-06-06 16:44

from django.db import migrations, models
import djangocms_text_ckeditor.fields
import smart_media.modelfields


class Migration(migrations.Migration):

    dependencies = [
        ('firm_info', '0009_alter_socialsharing_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='AppsBanner',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('application_type', models.CharField(choices=[('free_apply', 'Free apply'), ('job_offers', 'Job offers'), ('news', 'News'), ('trombinoscope', 'Trombinoscope')], max_length=13, unique=True)),
                ('image', smart_media.modelfields.SmartMediaField(blank=True, null=True, upload_to='firm/apps_banner/%y/%m', verbose_name='Image')),
                ('title', models.CharField(blank=True, max_length=150, null=True, verbose_name='Title')),
                ('description', djangocms_text_ckeditor.fields.HTMLField(blank=True, null=True, verbose_name='Description')),
            ],
            options={
                'verbose_name': 'App banner',
                'verbose_name_plural': 'App banners',
            },
        ),
    ]
