# Generated by Django 4.0.10 on 2023-05-26 11:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('firm_info', '0004_firmcontact_logo_firmcontact_logo_invert'),
    ]

    operations = [
        migrations.AddField(
            model_name='firmcontact',
            name='favicon',
            field=models.ImageField(blank=True, null=True, upload_to='firm/logo_inverted'),
        ),
    ]
