# Generated by Django 4.0.10 on 2023-06-12 13:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('firm_info', '0011_alter_firmcontact_favicon_alter_firmcontact_logo_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='appsbanner',
            name='application_type',
            field=models.CharField(choices=[('application_sent', 'Application sent'), ('free_apply', 'Free apply'), ('job_offers', 'Job offers'), ('news', 'News'), ('trombinoscope', 'Trombinoscope')], max_length=16, unique=True),
        ),
    ]
