# Generated by Django 4.0.10 on 2023-06-02 13:09

from django.db import migrations, models
import smart_media.modelfields


class Migration(migrations.Migration):

    dependencies = [
        ('firm_info', '0006_alter_firmcontact_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='SocialSharing',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('og_image', smart_media.modelfields.SmartMediaField(blank=True, null=True, upload_to='firm/social_sharing/%y/%m', verbose_name='OG Image')),
                ('og_description', models.TextField(blank=True, default='', max_length=180, verbose_name='OG Description')),
                ('og_twitter_site', models.CharField(blank=True, default='', max_length=100, verbose_name='OG Twitter Site')),
            ],
            options={
                'verbose_name': 'Social sharing',
                'verbose_name_plural': 'Social shares',
            },
        ),
        migrations.CreateModel(
            name='Tracking',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tag_analytic', models.CharField(blank=True, default='', max_length=100, verbose_name='Tag Analytic')),
            ],
            options={
                'verbose_name': 'Tracking',
                'verbose_name_plural': 'Trackings',
            },
        ),
    ]
