<p>Email: {{ email }}</p>
<p>Phone: {{ phone }}</p>
<p>Full address: {{ full_address }}</p>
<p>Address: {{ address }}</p>
<p>city: {{ city }}</p>
<p>postal code: {{ postal_code }}</p>
<p>country: {{ country }}</p>