
<!-- Social Media Link Start -->
  <div class="social-media-link social-link-white d-flex flex-column">
    {% if facebook %}
      <a target="_blank" href="{{ facebook }}" class="link-light mb-1 fs-3"><i class="icon-logo-facebook"></i></a>
    {% endif %}
    {% if linkedin %}
      <a target="_blank" href="{{ linkedin }}" class="link-light mb-1 fs-3"><i class="icon-logo-linkedin"></i></a>
    {% endif %}
    {% if twitter %}
      <a target="_blank" href="{{ twitter }}" class="link-light mb-1 fs-3"><i class="icon-logo-twitter"></i></a>
    {% endif %}
    {% if youtube %}
      <a target="_blank" href="{{ youtube }}" class="link-light mb-1 fs-3"><i class="icon-logo-youtube"></i></a>
    {% endif %}
    {% if instagram %}
      <a target="_blank" href="{{ instagram }}" class="link-light mb-1 fs-3"><i class="icon-logo-instagram"></i></a>
    {% endif %}
    {% if instagram %}
      <a target="_blank" href="{{ instagram }}" class="link-light mb-1 fs-3"><i class="icon-logo-instagram"></i></a>
    {% endif %}
    {% if glassdoor %}
      <a target="_blank" href="{{ glassdoor }}" class="link-light mb-1 fs-3"><i class="icon-logo-glassdoor"></i></a>
    {% endif %}
</div>
<!-- Social Media Link End -->
