# Generated by Django 4.0.10 on 2023-05-15 15:54

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='FirmContact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('phone_number', models.CharField(max_length=20)),
                ('email', models.EmailField(max_length=254)),
                ('address', models.CharField(max_length=255)),
                ('postal_code', models.CharField(max_length=20)),
                ('city', models.CharField(max_length=100)),
                ('country', models.CharField(max_length=100)),
            ],
            options={
                'verbose_name': 'Compagny contact informations',
            },
        ),
        migrations.CreateModel(
            name='Link',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(choices=[('linkedin', 'linkedin'), ('facebook', 'facebook'), ('twitter', 'twitter'), ('youtube', 'youtube'), ('instagram', 'instagram')], max_length=255)),
                ('url', models.URLField(max_length=255)),
                ('client_contact', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='firm_info.firmcontact')),
            ],
            options={
                'verbose_name': 'Social network link',
                'verbose_name_plural': 'Social networks links',
            },
        ),
    ]
