<ul class="list-inline d-flex my-2 mb-lg-0 justify-content-center justify-content-lg-start">
  {% if facebook %}
    <li class="list-inline-item">
      <a target="_blank" href="{{ facebook }}" class="link-primary">
        <i class="icon-logo-facebook fs-3 me-2"></i>
        </a>
    </li>
  {% endif %}

  {% if linkedin %}
    <li class="list-inline-item">
      <a target="_blank" href="{{ linkedin }}" class="link-primary">
        <i class="icon-logo-linkedin fs-3 me-2"></i>
        </a>
    </li>
  {% endif %}

  {% if twitter %}
    <li class="list-inline-item">
      <a target="_blank" href="{{ twitter }}" class="link-primary">
        <i class="icon-logo-twitter fs-3 me-2"></i>
        </a>
    </li>
  {% endif %}

  {% if youtube %}
    <li class="list-inline-item">
      <a target="_blank" href="{{ youtube }}" class="link-primary">
        <i class="icon-logo-youtube fs-3 me-2"></i>
        </a>
    </li>
  {% endif %}

  {% if instagram %}
    <li class="list-inline-item">
      <a target="_blank" href="{{ instagram }}" class="link-primary">
        <i class="icon-logo-instagram fs-3 me-2"></i>
        </a>
    </li>
  {% endif %}

  {% if glassdoor %}
    <li class="list-inline-item">
      <a target="_blank" href="{{ glassdoor }}" class="link-primary">
        <i class="icon-logo-glassdoor fs-3 me-2"></i>
        </a>
    </li>
  {% endif %}
</ul>