
{% load  i18n %}
{% if phone %}
  <a class="btn icon-call fs-8 text-white icon-lg" href="tel:{{ phone }}">
    <span class="d-none d-md-inline">{% trans 'Tel' %} {{ phone }}</span>
  </a>
{% else %}
{% endif %}
