# Generated by Django 4.0.10 on 2023-06-09 15:17

from django.db import migrations
import smart_media.modelfields


class Migration(migrations.Migration):

    dependencies = [
        ('firm_info', '0010_appsbanner'),
    ]

    operations = [
        migrations.AlterField(
            model_name='firmcontact',
            name='favicon',
            field=smart_media.modelfields.SmartMediaField(blank=True, null=True, upload_to='firm_info/firm_contact/favicon/%y/%m', verbose_name='Favicon'),
        ),
        migrations.AlterField(
            model_name='firmcontact',
            name='logo',
            field=smart_media.modelfields.SmartMediaField(blank=True, null=True, upload_to='firm_info/firm_contact/logo/%y/%m', verbose_name='Logo'),
        ),
        migrations.AlterField(
            model_name='firmcontact',
            name='logo_invert',
            field=smart_media.modelfields.SmartMediaField(blank=True, null=True, upload_to='firm_info/firm_contact/logo_invert/%y/%m', verbose_name='Logo invert'),
        ),
    ]
