# Generated by Django 4.0.10 on 2023-05-29 13:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('firm_info', '0005_firmcontact_favicon'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='firmcontact',
            options={'verbose_name': 'Company contact information', 'verbose_name_plural': 'Company contact information'},
        ),
    ]
